local ADDON_NAME = "GearGrinder";

local L = LibStub("AceLocale-3.0"):GetLocale(ADDON_NAME, true);

local CURRENCIES = {
	-- General
	HONOR = 392,
	CONQUEST = 390,
	-- MoP
	ELDER = 697,
	LESSER = 738,
	MOGU = 752,
	TIMELESS = 777,
	WARSEAL = 776,
	-- WoD
	APEXIS = 823,   -- Apexis Crystals
	GARRISON = 824, -- Garrisson Resources
	FATE = 994,     -- Seal of Tempered Fate
};

local WHITE_BRIGHT_COLOR = "|cffFFFFFF"
local YELLOW_NEON_COLOR = "|cffFFFF00"
local RED_NEON_COLOR = "|cffFF0000"
local ORANGE_NEON_COLOR = "|cffEE6622"
local EPIC_COLOR = "|cffA335EE"
local GREEN_NEON_COLOR = "|cff00FF00"
local GREY_COLOR = "|cff9d9d9d"
local END_COLOR = FONT_COLOR_CODE_CLOSE
local INFO_COLOR = "|cFFFFCC00"

-- Options for AceOptions

GG_Options = {
	name = L.core.options.name,
	desc = L.core.desc,
	type = "group",
	args = {
		general = {
			name = L.core.options.options,
			type = "group",
			inline = true,
			order = 1,
			args = {
				x = { 
					name = "General options",
					type = "description",
					fontSize = "small",
					order = 1,
				},
				combat = { -- Disable the tooltip if in combat
					name = L.core.options.combat,
					desc = L.core.options.combatDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetShowCombat(v) end,
					get = function(i) return GearGrinder:GetShowCombat() end,
					order = 24,
				},
				minimap = { -- Minimap Button
					name = L.core.options.minimap,
					desc = L.core.options.minimapDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetMinimap(v) end,
					get = function(i) return GearGrinder:GetMinimap() end,
					order = 25,
				},
				filtering = { -- enable/disable character filtering
					name = L.core.options.filtering,
					desc = L.core.options.filteringDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetFiltering(v) end,
					get = function(i) return GearGrinder:GetFiltering() end,
					order = 26,
				},
				ttScale = { -- UI Scale of the tooltip
					name = L.core.options.scale,
					desc = L.core.options.scaleDesc,
					type = "range",
					max = 2,
					min = 0.5,
					step = 0.1,
					set = function(i,v) GearGrinder:SetTTScale(v) end,
					get = function(i) return GearGrinder:GetTTScale() end,
					order = 28,
				},
				sortOrder = { -- Sort Order
					name = L.core.options.sortOrder,
					desc = L.core.options.sortOrderDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GearGrinder:SetSortOrder(v) end,
					get = function(i) return GearGrinder:GetSortOrder() end,
					values = { 	
						[1] = "Level -> iLevel",
						[2] = "Character Name",
						[3] = "Class -> Character Name", 
						[5] = "iLevel"},
					order = 29,
				},
				reset_dayofweek = { -- Reset Day of Week
					name = L.core.options.resetDayOfWeek,
					desc = L.core.options.resetDayOfWeekDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GearGrinder:SetResetDayOfWeek(v) end,
					get = function(i) return GearGrinder:GetResetDayOfWeek() end,
					values = { 	
						[1] = "Monday",
						[2] = "Tuesday", 
						[3] = "Wednesday",
						[4] = "Thursday", 
						[5] = "Friday",
						[6] = "Saturday",
						[0] = "Sunday" },
					order = 30,
				},
				reset_hour = { -- Reset Hour of day
					name = L.core.options.resetHour,
					desc = L.core.options.resetHourDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GearGrinder:SetResetHour(v) end,
					get = function(i) return GearGrinder:GetResetHour() end,
					values = { 	
						[0] = "12am",
						[1] = "1am",
						[2] = "2am",
						[3] = "3am",
						[4] = "4am",
						[5] = "5am",
						[6] = "6am",
						[7] = "7am",
						[8] = "8am",
						[9] = "9am",
						[10] = "10am",
						[11] = "11am",
						[12] = "12pm",
						[13] = "1pm",
						[14] = "2pm",
						[15] = "3pm",
						[16] = "4pm",
						[17] = "5pm",
						[18] = "6pm",
						[19] = "7pm",
						[20] = "8pm",
						[21] = "9pm",
						[22] = "10pm",
						[23] = "11pm"},
					order = 31,
				},
				daily_reset_hour = { -- Dailies Reset Hour of day
					name = L.core.options.dailyResetHour,
					desc = L.core.options.dailyResetHourDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GearGrinder:SetDailyResetHour(v) end,
					get = function(i) return GearGrinder:GetDailyResetHour() end,
					values = { 	
						[0] = "12am",
						[1] = "1am",
						[2] = "2am",
						[3] = "3am",
						[4] = "4am",
						[5] = "5am",
						[6] = "6am",
						[7] = "7am",
						[8] = "8am",
						[9] = "9am",
						[10] = "10am",
						[11] = "11am",
						[12] = "12pm",
						[13] = "1pm",
						[14] = "2pm",
						[15] = "3pm",
						[16] = "4pm",
						[17] = "5pm",
						[18] = "6pm",
						[19] = "7pm",
						[20] = "8pm",
						[21] = "9pm",
						[22] = "10pm",
						[23] = "11pm"},
					order = 32,
				},				
				--[[instruction = { -- button to show the help screen
					name = L.core.options.instruction,
					desc = L.core.options.instructionDesc,
					type = "execute",
					confirm = false,
					func = function(i) return GearGrinder:ShowHelp() end,
					order = 20,
				},]]
				purge = {
					name = L.core.options.purge,
					desc = L.core.options.purgeDesc,
					type = "execute",
					func = function(i) GearGrinder:PurgeDB(false) end,
					confirm = true,
					order = 35,
				},
				toonRealm = { -- Show Toons from all Realms
					name = L.core.options.ToonRealm,
					desc = L.core.options.ToonRealmDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonRealm(v) end,
					get = function(i) return GearGrinder:GetToonRealm() end,
					order = 41,
				},
				realmGroup = { -- Show a group for the realm
					name = L.core.options.ToonRealmGroup,
					desc = L.core.options.ToonRealmGroupDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonRealmGroup(v) end,
					get = function(i) return GearGrinder:GetToonRealmGroup() end,
					order = 42,
				},
				showRealm = { -- Show Toons from all Realms
					name = L.core.options.ToonShowRealm,
					desc = L.core.options.ToonShowRealmDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonShowRealm(v) end,
					get = function(i) return GearGrinder:GetToonShowRealm() end,
					order = 43,
				},
			},
		},

		ttToons = {
			name = "Character Settings",
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Columns are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				toonLevel = { -- Show Level
					name = L.core.options.ToonLevel,
					--desc = L.core.options.tooniLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonLevel(v) end,
					get = function(i) return GearGrinder:GetToonLevel() end,
					order = 8,
				},
				tooniELevel = { -- Show iELevel
					name = L.core.options.TooniELevel,
					--desc = L.core.options.tooniLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetTooniELevel(v) end,
					get = function(i) return GearGrinder:GetTooniELevel() end,
					order = 9,
				},
				tooniLevel = { -- Show iLevel
					name = L.core.options.TooniLevel,
					--desc = L.core.options.tooniLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetTooniLevel(v) end,
					get = function(i) return GearGrinder:GetTooniLevel() end,
					order = 10,
				},
				toonHP = { -- Show Honor Points
					name = GetCurrencyInfo(CURRENCIES.HONOR), --L.core.options.ToonHP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonHP(v) end,
					get = function(i) return GearGrinder:GetToonHP() end,
					order = 14,
				},
				toonCP = { -- Show Conquest Points
					name = GetCurrencyInfo(CURRENCIES.CONQUEST), --L.core.options.ToonCP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonCP(v) end,
					get = function(i) return GearGrinder:GetToonCP() end,
					order = 15,
				},
				toonCPCap = { -- Show Conquest Point Cap
					name = L.core.options.ToonCPCap,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonCPCap(v) end,
					get = function(i) return GearGrinder:GetToonCPCap() end,
					order = 16,
				},
				toonTimeless = { -- Show Timeless Coins
					name = GetCurrencyInfo(CURRENCIES.TIMELESS), --L.core.options.ToonTimeless,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonTimeless(v) end,
					get = function(i) return GearGrinder:GetToonTimeless() end,
					order = 17,
				},
				toonApexis = { -- Show Apexis Crystals
					name = GetCurrencyInfo(CURRENCIES.APEXIS), --L.core.options.ToonTimeless,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonApexis(v) end,
					get = function(i) return GearGrinder:GetToonApexis() end,
					order = 18,
				},
				toonGarRes = { -- Show Garrison Resources
					name = GetCurrencyInfo(CURRENCIES.GARRISON), --L.core.options.ToonTimeless,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonGarRes(v) end,
					get = function(i) return GearGrinder:GetToonGarRes() end,
					order = 19,
				},
				toonCharm = { -- Show Charms
					name = L.core.options.ToonCharm,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonCharms(v) end,
					get = function(i) return GearGrinder:GetToonCharms() end,
					order = 20,
				},
				toonActivity = { -- Show Daily/Weekly Activity indicators
					name = "Show " .. L.core.options.ToonActivity,
					--desc = L.core.options.activityDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonActivity(v) end,
					get = function(i) return GearGrinder:GetToonActivity() end,
					order = 21,
				},
				toonProfCD = { -- enable/disable profession cooldowns
					name = L.core.options.ToonProfCD,
					--desc = L.core.options.profCDDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonProfCD(v) end,
					get = function(i) return GearGrinder:GetToonProfCD() end,
					order = 22,
				},
				toonFarm = { -- enable/disable farming
					name = L.core.options.ToonFarm,
					--desc = L.core.options.farmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonFarm(v) end,
					get = function(i) return GearGrinder:GetToonFarm() end,
					order = 23,
				},
				
			},
		},
		
		ttCharms = {
			name = "Bonus Roll Tokens",
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Bonus Roll Tokens are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				charms = { -- Show Charms
					name = "Show " .. L.core.options.ToonCharm,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetToonCharms(v) end,
					get = function(i) return GearGrinder:GetToonCharms() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				charmLesser = { -- 
					name = GetCurrencyInfo(CURRENCIES.LESSER),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetCharmLesser(v) end,
					get = function(i) return GearGrinder:GetCharmLesser() end,
					width = "full",
					order = 21,
				},	
				charmElder = { -- 
					name = GetCurrencyInfo(CURRENCIES.ELDER),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetCharmElder(v) end,
					get = function(i) return GearGrinder:GetCharmElder() end,
					width = "full",
					order = 22,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				charmMogu = { -- 
					name = GetCurrencyInfo(CURRENCIES.MOGU),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetCharmMogu(v) end,
					get = function(i) return GearGrinder:GetCharmMogu() end,
					width = "full",
					order = 31,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				
				charmWarSeal = { -- 
					name = GetCurrencyInfo(CURRENCIES.WARSEAL),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetCharmWarSeal(v) end,
					get = function(i) return GearGrinder:GetCharmWarSeal() end,
					width = "full",
					order = 41,
				},	
				head4 = { 
					name = "Tier 17",
					type = "header",
					order = 50,
				},
				charmFate = { -- 
					name = GetCurrencyInfo(CURRENCIES.FATE),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetCharmFate(v) end,
					get = function(i) return GearGrinder:GetCharmFate() end,
					width = "full",
					order = 51,
				},	
		
			},
		},
		
		ttActivities = {
			name = L.core.options.ttActivity,
			type = "group",
			inline = true,
			order = 3,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure the Daily/Weekly Activities|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				
				activity = { -- Show Daily/Weekly Activity indicators
					name = "Show " .. L.core.options.ToonActivity,
					--desc = L.core.options.activityDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonActivity(v) end,
					get = function(i) return GearGrinder:GetToonActivity() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Daily Activities",
					type = "header",
					order = 13,
				},
				D = { -- Show Daily Normal Dungeon Quest
					name = L.core.options.ActivityD,
					--desc = L.core.options.DDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityD(v) end,
					get = function(i) return GearGrinder:GetActivityD() end,
					width = "full",
					order = 21,
				},
				H = { -- Show Daily Heroic
					name = L.core.options.ActivityH,
					--desc = L.core.options.HDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityH(v) end,
					get = function(i) return GearGrinder:GetActivityH() end,
					width = "full",
					order = 22,
				},
				HS = { -- Show Daily Heroic Scenario
					name = L.core.options.ActivityHS,
					--desc = L.core.options.HSDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityHS(v) end,
					get = function(i) return GearGrinder:GetActivityHS() end,
					width = "full",
					order = 23,
				},
				S = { -- Show Daily Scenario
					name = L.core.options.ActivityS,
					--desc = L.core.options.SDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityS(v) end,
					get = function(i) return GearGrinder:GetActivityS() end,
					width = "full",
					order = 24,
				},
				C = { -- Show Daily Challenge Mode Quest
					name = L.core.options.ActivityC,
					--desc = L.core.options.CDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityC(v) end,
					get = function(i) return GearGrinder:GetActivityC() end,
					width = "full",
					order = 25,
				},
				R = { -- Show Daily Ring of Blood Quest
					name = L.core.options.ActivityR,
					--desc = L.core.options.CDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetActivityR(v) end,
					get = function(i) return GearGrinder:GetActivityR() end,
					width = "full",
					order = 26,
				},
				desc2 = { 
					name = " ",
					type = "description",
					fontSize = "large",
					order = 31,
				},
				head2 = { 
					name = "Weekly Activities",
					type = "header",
					order = 32,
				},

			},
		},

		ttProfs = {
			name = L.core.options.ttProfs,
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Profession Cooldowns are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				profCD = { -- enable/disable profession cooldowns
					name = "Show " .. L.core.options.ToonProfCD,
					--desc = L.core.options.profCDDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetToonProfCD(v) end,
					get = function(i) return GearGrinder:GetToonProfCD() end,
					order = 11,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Mists of Pandaria",
					type = "header",
					order = 13,
				},
				ProfAlc = { -- Alchemy [Transmute: Living Steel]
					name = L.core.options.ProfAlc,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfAlc(v) end,
					get = function(i) return GearGrinder:GetProfAlc() end,
					width = "full",
					order = 21,
				},
				ProfBS = { -- Blacksmith  [Lightning Steel Ingot]
					name = L.core.options.ProfBS,
					--desc = L.core.options.ProfBSDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfBS(v) end,
					get = function(i) return GearGrinder:GetProfBS() end,
					width = "full",
					order = 22,
				},
				ProfBS2 = { -- Blacksmith  [Balanced Trillium Ingot]
					name = L.core.options.ProfBS2,
					--desc = L.core.options.ProfBSDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfBS2(v) end,
					get = function(i) return GearGrinder:GetProfBS2() end,
					width = "full",
					order = 23,
				},
				ProfEnch = { -- Enchanting  [Sha Crystal]
					name = L.core.options.ProfEnch,
					--desc = L.core.options.ProfEnchDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfEnch(v) end,
					get = function(i) return GearGrinder:GetProfEnch() end,
					width = "full",
					order = 24,
				},
				ProfEng = { -- Engineering [Jard's Peculiar Energy Source]
					name = L.core.options.ProfEng,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfEng(v) end,
					get = function(i) return GearGrinder:GetProfEng() end,
					width = "full",
					order = 25,
				},
				ProfScribe = { -- Inscription [Scroll of Wisdom]
					name = L.core.options.ProfScribe,
					--desc = L.core.options.ProfScribeDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfScribe(v) end,
					get = function(i) return GearGrinder:GetProfScribe() end,
					width = "full",
					order = 26,
				},
				ProfJCGem = { -- Jewelcrafting [Facets of Research]
					name = L.core.options.ProfJCGem,
					--desc = L.core.options.ProfJCGemDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfJCGem(v) end,
					get = function(i) return GearGrinder:GetProfJCGem() end,
					width = "full",
					order = 27,
				},
				ProfJCHeart = { -- Jewelcrafting [Serpent's Heart]
					name = L.core.options.ProfJCHeart,
					--desc = L.core.options.ProfJCHeartDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfJCHeart(v) end,
					get = function(i) return GearGrinder:GetProfJCHeart() end,
					width = "full",
					order = 28,
				},
				ProfLW = { -- Leatherworking [Magnificence of Leather]
					name = L.core.options.ProfLW,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfLW(v) end,
					get = function(i) return GearGrinder:GetProfLW() end,
					width = "full",
					order = 29,
				},
				ProfLW2 = { -- Leatherworking [Hardened Magnificant Hide]
					name = L.core.options.ProfLW2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfLW2(v) end,
					get = function(i) return GearGrinder:GetProfLW2() end,
					width = "full",
					order = 30,
				},
				ProfTailor = { -- Tailoring  [Imperial Silk]
					name = L.core.options.ProfTailor,
					--desc = L.core.options.ProfTailorDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfTailor(v) end,
					get = function(i) return GearGrinder:GetProfTailor() end,
					width = "full",
					order = 31,
				},
				ProfTailor2 = { -- Tailoring  [Celestial Cloth]
					name = L.core.options.ProfTailor2,
					--desc = L.core.options.ProfTailorDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfTailor2(v) end,
					get = function(i) return GearGrinder:GetProfTailor2() end,
					width = "full",
					order = 32,
				},
				head2 = { 
					name = "Warlords of Draenor",
					type = "header",
					order = 40,
				},
				ProfWoDAlc1 = { -- 
					name = L.core.options.ProfWoDAlc1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDAlc1(v) end,
					get = function(i) return GearGrinder:GetProfWoDAlc1() end,
					width = "full",
					order = 41,
				},
				ProfWoDAlc2 = { -- 
					name = L.core.options.ProfWoDAlc2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDAlc2(v) end,
					get = function(i) return GearGrinder:GetProfWoDAlc2() end,
					width = "full",
					order = 42,
				},
				ProfWoDBS1 = { -- 
					name = L.core.options.ProfWoDBS1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDBS1(v) end,
					get = function(i) return GearGrinder:GetProfWoDBS1() end,
					width = "full",
					order = 43,
				},
				ProfWoDBS2 = { -- 
					name = L.core.options.ProfWoDBS2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDBS2(v) end,
					get = function(i) return GearGrinder:GetProfWoDBS2() end,
					width = "full",
					order = 44,
				},
				ProfWoDEnc1 = { -- 
					name = L.core.options.ProfWoDEnc1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDEnc1(v) end,
					get = function(i) return GearGrinder:GetProfWoDEnc1() end,
					width = "full",
					order = 45,
				},
				ProfWoDEnc2 = { -- 
					name = L.core.options.ProfWoDEnc2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDEnc2(v) end,
					get = function(i) return GearGrinder:GetProfWoDEnc2() end,
					width = "full",
					order = 46,
				},
				ProfWoDEng1 = { -- 
					name = L.core.options.ProfWoDEng1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDEng1(v) end,
					get = function(i) return GearGrinder:GetProfWoDEng1() end,
					width = "full",
					order = 47,
				},
				ProfWoDEng2 = { -- 
					name = L.core.options.ProfWoDEng2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDEng2(v) end,
					get = function(i) return GearGrinder:GetProfWoDEng2() end,
					width = "full",
					order = 48,
				},
				ProfWoDScribe1 = { -- 
					name = L.core.options.ProfWoDScribe1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDScribe1(v) end,
					get = function(i) return GearGrinder:GetProfWoDScribe1() end,
					width = "full",
					order = 49,
				},
				ProfWoDScribe2 = { -- 
					name = L.core.options.ProfWoDScribe2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDScribe2(v) end,
					get = function(i) return GearGrinder:GetProfWoDScribe2() end,
					width = "full",
					order = 50,
				},
				ProfWoDJC1 = { -- 
					name = L.core.options.ProfWoDJC1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDJC1(v) end,
					get = function(i) return GearGrinder:GetProfWoDJC1() end,
					width = "full",
					order = 51,
				},
				ProfWoDJC2 = { -- 
					name = L.core.options.ProfWoDJC2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDJC2(v) end,
					get = function(i) return GearGrinder:GetProfWoDJC2() end,
					width = "full",
					order = 52,
				},
				ProfWoDLW1 = { -- 
					name = L.core.options.ProfWoDLW1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDLW1(v) end,
					get = function(i) return GearGrinder:GetProfWoDLW1() end,
					width = "full",
					order = 53,
				},
				ProfWoDLW2 = { -- 
					name = L.core.options.ProfWoDLW2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDLW2(v) end,
					get = function(i) return GearGrinder:GetProfWoDLW2() end,
					width = "full",
					order = 54,
				},
				ProfWoDTailor1 = { -- 
					name = L.core.options.ProfWoDTailor1,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDTailor1(v) end,
					get = function(i) return GearGrinder:GetProfWoDTailor1() end,
					width = "full",
					order = 55,
				},
				ProfWoDTailor2 = { -- 
					name = L.core.options.ProfWoDTailor2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetProfWoDTailor2(v) end,
					get = function(i) return GearGrinder:GetProfWoDTailor2() end,
					width = "full",
					order = 56,
				},

			},
		},

		ttRaids = {
			name = L.core.options.ttRaids,
			type = "group",
			inline = true,
			order = 5,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Raids are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				raid = { -- Show the LFR section the tooltip
					name = L.core.options.Raid,
					desc = L.core.options.RaidDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetRaid(v) end,
					get = function(i) return GearGrinder:GetRaid() end,
					order = 7,
				},
				raidLFR = { -- Show the LFR section the tooltip
					name = L.core.options.RaidLFR,
					desc = L.core.options.RaidLFRDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetRaidLFR(v) end,
					get = function(i) return GearGrinder:GetRaidLFR() end,
					order = 8,
				},
				raidNormal = {  -- Show the Normal saves in the Raid section
					name = L.core.options.RaidNormal,
					desc = L.core.options.RaidNormalDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidNormal(v) end,
					get = function(i) return GearGrinder:GetRaidNormal() end,
					order = 9,
				},
				raidHeroic = {  -- Show the Heroic saves in the Raid section
					name = L.core.options.RaidHeroic,
					desc = L.core.options.RaidHeroicDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidHeroic(v) end,
					get = function(i) return GearGrinder:GetRaidHeroic() end,
					--hidden = true,
					order = 10,
				},
				raidMythic = {  -- Show the non-LFR saves in the Raid section
					name = L.core.options.RaidMythic,
					desc = L.core.options.RaidMythicDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidMythic(v) end,
					get = function(i) return GearGrinder:GetRaidMythic() end,
					--hidden = true,
					order = 11,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				RaidMV = { -- 
					name = "Mogu'shan Vaults", --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidMV(v) end,
					get = function(i) return GearGrinder:GetRaidMV() end,
					width = "full",
					order = 21,
				},	
				RaidHoF = { -- 
					name = "Heart of Fear", --L.core.options.RaidHoF,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidHoF(v) end,
					get = function(i) return GearGrinder:GetRaidHoF() end,
					width = "full",
					order = 22,
				},	
				RaidToES = { -- 
					name = "Terrace of Endless Spring", --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidToES(v) end,
					get = function(i) return GearGrinder:GetRaidToES() end,
					width = "full",
					order = 23,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				RaidToT = { -- 
					name = "Throne of Thunder", --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidToT(v) end,
					get = function(i) return GearGrinder:GetRaidToT() end,
					width = "full",
					order = 31,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				RaidSoO = { -- 
					name = "Siege of Orgrimmar", --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidSoO(v) end,
					get = function(i) return GearGrinder:GetRaidSoO() end,
					width = "full",
					order = 41,
				},	
				head4 = { 
					name = "Tier 17",
					type = "header",
					order = 50,
				},
				RaidHM = { -- 
					name = "Highmaul", --L.core.options.RaidHM,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidHM(v) end,
					get = function(i) return GearGrinder:GetRaidHM() end,
					width = "full",
					order = 51,
				},	
				RaidBrF = { -- 
					name = "Blackrock Foundry", --L.core.options.RaidBRF,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetRaidBRF(v) end,
					get = function(i) return GearGrinder:GetRaidBRF() end,
					width = "full",
					order = 52,
				},	
			},
		},

		ttGarrison = {
			name = L.core.options.ttGarrison,
			type = "group",
			inline = true,
			order = 5,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure the Garrison display|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				gar = { -- Show the LFR section the tooltip
					name = L.core.options.Garrison,
					desc = L.core.options.GarrisonDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetGarrison(v) end,
					get = function(i) return GearGrinder:GetGarrison() end,
					order = 8,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head1 = { 
					name = "Garrison Columns",
					type = "header",
					order = 20,
				},
				garLevel = { 
					name = "Level",
					desc = "Will show 1, 2 or 3 for the level of the Garrison.",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonLevel(v) end,
					get = function(i) return GearGrinder:GetGarrisonLevel() end,
					width = "full",
					order = 21,
				},
				garGarRes = { -- Show Garrison Resources
					name = GetCurrencyInfo(CURRENCIES.GARRISON), --L.core.options.ToonTimeless,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonResource(v) end,
					get = function(i) return GearGrinder:GetGarrisonResource() end,
					order = 22,
				},
				garMission = { 
					name = "Mission Progress   [" .. YELLOW_NEON_COLOR .. "Complete" .. END_COLOR .. ", " .. RED_NEON_COLOR .. "Inprogress" .. END_COLOR .. "]",
					desc = "Will show the Completed and Inprogress mission counts",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonMission(v) end,
					get = function(i) return GearGrinder:GetGarrisonMission() end,
					width = "full",
					order = 23,
				},
				garShipment = { 
					name = "Work Order Progress   [" .. GREEN_NEON_COLOR .. "Available" .. END_COLOR .. ", " .. YELLOW_NEON_COLOR .. "Complete" .. END_COLOR .. ", " .. RED_NEON_COLOR .. "Inprogress" .. END_COLOR .. "]",
					desc = "Will show the Available, Completed and Inprogress work order counts",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonShipment(v) end,
					get = function(i) return GearGrinder:GetGarrisonShipment() end,
					width = "full",
					order = 24,
				},
				garActivity = { 
					name = "Activity Details",
					desc = "Will show the activities both available and completed in the characters garrison",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonActivity(v) end,
					get = function(i) return GearGrinder:GetGarrisonActivity() end,
					width = "full",
					order = 25,
				},
				garFollower = { 
					name = "Follower Activity   [" .. GREEN_NEON_COLOR .. "Available" .. END_COLOR .. ", " .. YELLOW_NEON_COLOR .. "Complete" .. END_COLOR .. ", " .. RED_NEON_COLOR .. "Inprogress" .. END_COLOR .. "]",
					desc = "Will show the Available, Complete and Inprogress status of the characters followers",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonFollower(v) end,
					get = function(i) return GearGrinder:GetGarrisonFollower() end,
					width = "full",
					order = 26,
				},
				garBuilding = { 
					name = "Building Status   [" .. GREEN_NEON_COLOR .. "Active" .. END_COLOR .. ", " .. YELLOW_NEON_COLOR .. "Complete" .. END_COLOR .. ", " .. RED_NEON_COLOR .. "Inprogress" .. END_COLOR .. "]",
					desc = "Will show the Active, Complete and Inprogress status of the characters buildings and upgrades",
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonBuilding(v) end,
					get = function(i) return GearGrinder:GetGarrisonBuilding() end,
					width = "full",
					order = 27,
				},
				head2 = { 
					name = "Garrison Activities Details",
					type = "header",
					order = 40,
				},
				garMine = { -- 
					name = "Mining [" .. GREEN_NEON_COLOR .. "M" .. END_COLOR .. "]",
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonActivityMine(v) end,
					get = function(i) return GearGrinder:GetGarrisonActivityMine() end,
					width = "full",
					order = 41,
				},
				garHerb = { -- 
					name = "Herbing [" .. GREEN_NEON_COLOR .. "H" .. END_COLOR .. "]", 
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetGarrisonActivityHerb(v) end,
					get = function(i) return GearGrinder:GetGarrisonActivityHerb() end,
					width = "full",
					order = 42,
				},
			},
		},

		ttBoss = {
			name = L.core.options.ttBoss,
			type = "group",
			inline = true,
			order = 6,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which World Bosses are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				worldBoss = { -- Show World Boss Status
					name = L.core.options.boss,
					desc = L.core.options.bossDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetWorldBoss(v) end,
					get = function(i) return GearGrinder:GetWorldBoss() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				BossSha = { -- 
					name = L.core.BossShaOfAnger,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossSha(v) end,
					get = function(i) return GearGrinder:GetBossSha() end,
					width = "full",
					order = 21,
				},	
				BossGalleon = { -- 
					name = L.core.BossGalleon,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossGalleon(v) end,
					get = function(i) return GearGrinder:GetBossGalleon() end,
					width = "full",
					order = 22,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				BossNalak = { -- 
					name = L.core.BossNalak,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossNalak(v) end,
					get = function(i) return GearGrinder:GetBossNalak() end,
					width = "full",
					order = 31,
				},	
				BossOondasta = { -- 
					name = L.core.BossOondasta,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossOondasta(v) end,
					get = function(i) return GearGrinder:GetBossOondasta() end,
					width = "full",
					order = 32,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				BossCelestial = { -- 
					name = L.core.BossCelestial,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossCelestial(v) end,
					get = function(i) return GearGrinder:GetBossCelestial() end,
					width = "full",
					order = 41,
				},	
				BossOrdos = { -- 
					name = L.core.BossOrdos,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossOrdos(v) end,
					get = function(i) return GearGrinder:GetBossOrdos() end,
					width = "full",
					order = 42,
				},	
				head4 = { 
					name = "Tier 17",
					type = "header",
					order = 50,
				},
				BossDrov = { -- 
					name = L.core.BossDrov,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossDrov(v) end,
					get = function(i) return GearGrinder:GetBossDrov() end,
					width = "full",
					order = 51,
				},	
				BossTarina = { -- 
					name = L.core.BossTarina,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossTarina(v) end,
					get = function(i) return GearGrinder:GetBossTarina() end,
					width = "full",
					order = 52,
				},	
				BossRukhmar = { -- 
					name = L.core.BossRukhmar,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetBossRukhmar(v) end,
					get = function(i) return GearGrinder:GetBossRukhmar() end,
					width = "full",
					order = 53,
				},	
			},
		},
		
		ldbOpt = {
			name = L.core.options.ldb,
			type = "group",
			inline = true,
			order = 7,
			cmdHidden = true,
			args = {
				ldbText = {  -- Toggle the LDB Text competely
					name = L.core.options.ldbText,
					desc = L.core.options.ldbTextDesc,
					type = "toggle",
					get = function(i) return GearGrinder:GetLDB() end,
					set = function(i,v) GearGrinder:SetLDB(v) end,
					order = 1,
				},
				ldbLabel = { -- Toggle the characters name
					name = L.core.options.ldbSource,
					desc = L.core.options.ldbSourceDesc,
					type = "toggle",
					get = function(i) return GearGrinder:GetLDBlabel() end,
					set = function(i,v) GearGrinder:SetLDBlabel(v) end,
					order = 2,
				},
				ldbTextColor = { -- Toggle the Colorizing of the LDB Text
					name = L.core.options.ldbTextColor,
					desc = L.core.options.ldbTextColorDesc,
					type = "toggle",
					set = function(i,v) GearGrinder:SetLDBTextColor(v) end,
					get = function(i) return GearGrinder:GetLDBTextColor() end,
					order = 3,
				},
				head4 = { 
					name = "Display Options",
					type = "header",
					order = 10,
				},
				ldbDisplayLFR = { -- Display LFR completions on the LDB Button
					name = L.core.options.ldbDisplayLFR,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetLDBDisplayLFR(v) end,
					get = function(i) return GearGrinder:GetLDBDisplayLFR() end,
					order = 11,
				},
				ldbDisplayRaid = { -- Display Raid completions on the LDB Button
					name = L.core.options.ldbDisplayRaid,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetLDBDisplayRaid(v) end,
					get = function(i) return GearGrinder:GetLDBDisplayRaid() end,
					order = 12,
				},
				ldbDisplayRoll = { -- Display Bonus Roll tokens on the LDB Button
					name = L.core.options.ldbDisplayRoll,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetLDBDisplayRoll(v) end,
					get = function(i) return GearGrinder:GetLDBDisplayRoll() end,
					order = 13,
				},
				ldbDisplayBoss = { -- Display World Boss kills on the LDB Button
					name = L.core.options.ldbDisplayBoss,
					type = "toggle",
					width = "full",
					set = function(i,v) GearGrinder:SetLDBDisplayBoss(v) end,
					get = function(i) return GearGrinder:GetLDBDisplayBoss() end,
					order = 14,
				},
			},
		},
        
		Background = {
			type = "group",
			name = "Background Options",
			guiInline = true,
			order = 8,
			get = function(i) return GearGrinder:GetBgGeneric(i) end,
			set = function(i, v) GearGrinder:SetBgGeneric(i, v) end,
			args = {
				Texture = {
					type = "select", dialogControl = 'LSM30_Background',
					order = 1,
					name = "Background Texture",
					desc = "Texture to use for the frame's background",
					values = AceGUIWidgetLSMlists.background,
				},
				BorderTexture = {
					type = "select", dialogControl = 'LSM30_Border',
					order = 2,
					name = "Border Texture",
					desc = "Texture to use for the tooltip's border",
					values = AceGUIWidgetLSMlists.border,
				},
				Color = {
					type = "color",
					order = 3,
					name = "Background Color",
					desc = "Tooltip's background color",
					hasAlpha = true,
					get = function(i) return GearGrinder:GetBGColor() end,
					set = function(i, r, g, b, a) GearGrinder:SetBGColor(r, g, b, a) end,
				},
				AltLineColor = {
					type = "color",
					order = 4,
					name = "Alternate Line Color",
					desc = "Tooltip's alternate line background color",
					hasAlpha = true,
					get = function(i) return GearGrinder:GetAltLineColor() end,
					set = function(i, r, g, b, a) GearGrinder:SetAltLineColor(r, g, b, a) end,
				},
				BorderColor = {
					type = "color",
					order = 5,
					name = "Border Color",
					desc = "Tooltip's border color",
					hasAlpha = true,
					get = function(i) return GearGrinder:GetBGBorderColor() end,
					set = function(i, r, g, b, a) GearGrinder:SetBGBorderColor(r, g, b, a)	end,
				},
				Tile = {
					type = "toggle",
					order = 6,
					name = "Tile Background",
					desc = "Tile the background texture",
				},
				TileSize = {
					type = "range",
					order = 7,
					name = "Background Tile Size",
					desc = "The size used to tile the background texture",
					min = 16, max = 256, step = 1,
					disabled = function() return not GearGrinder:GetBGTile() end,
				},
				EdgeSize = {
					type = "range",
					order = 8,
					name = "Border Thickness",
					desc = "The thickness of the border",
					min = 1, max = 16, step = 1,
				},
				AltLine = {
					type = "toggle",
					order = 9,
					name = "Show Alternate Line Color?",
					desc = "Alternate Line background color",
					set = function(i,v) GearGrinder:SetAltLine(v) end,
					get = function(i) return GearGrinder:GetAltLine() end,
				},
			},
		},		
		
		-- Console Only
		options = {
			name = L.core.options.name,
			desc = L.core.options.optionDesc,
			type = "input",
			set = function(i) GearGrinder:ShowOptions() end,
			hidden = true,
			order = 49,
			guiHidden = true,
			cmdHidden = false,
		},
		--[[debug = { -- Debug mode
			name = 'Debug Mode',
			type = "toggle",
			set = function(i,v) GearGrinder:SetDebug(v) end,
			get = function() return GearGrinder:GetDebug() end,
			order = 50,
			hidden = true,
			guiHidden = true,
			cmdHidden = false,
		},]]
	},
};

GG_Defaults = {
	global = {
		daily_reset_hour = 2,	-- Hour the dailies are reset ie. 2AM
		reset_hour = 3,			-- Hour the VP Cap is reset ie. 3AM
		reset_dayofweek = 2,	-- Day of week when VP Cap is reset ie. Tuesday
		combat = false,			-- don't show in combat
		filtering = true,		-- allow characater filtering.
		ttScale = 1,
		ToonRealm = true,			-- show characters from all realms
		ToonRealmGroup = true,		--  group the characters by realm
		ToonShowRealm = false,		-- show the realm name on the character name
		progress_orange = nil,
		progress_yellow = nil,
		JPStandardMax = nil,
		VPStandardMax = nil,
		VPStandardCapMax = nil,
		CPStandardCapMax = 4200,
		HPStandardMax = 4000,
		minimap = {
			hide = false,		-- Minimap Icon
		},
		sortOrder = 5,			-- sort order of iLevel
		version = 1,			-- Version for future referance
		worldBoss = true,		-- Show World Boss status
		show_Icons = false,		-- Show the Icons on the tooltip
		
		-- Garrison Settings
		gar = true,				-- show the garrison section
		garLevel = true,		-- show the garrison level
		garResource = true,		-- show the garrison resources
		garMission = true,		-- show the garrison Missions
		garShipment = true,		-- show the garrison Shipments
		garActivity = true,		-- show the garrison Activities
		garFollower = true,		-- show the garrison Followers
		garBuilding = true,		-- show the garrison Buildings
		----garrison activities
		garActivityMine = true,	-- show the garrison Mining
		garActivityHerb = true,	-- show the garrison Herbing

		-- Raid Settings
		raid = true,				-- Show the LFR values on the tooltip
		raidLFR = true,
		raidNormal = true,			-- Show the Non-LFR save details on the tooltip
		lfrFlex = nil,
		raidHeroic = true,
		raidMystic = true,
		
		-- LDB settings
		ldbTextColor = true,	-- LDB Text Colorize?
		ldbText = true,			-- LDB Text
		ldbLabel = false,		-- LDB Label
		ldbDisplayLFR = true,	-- LDB Show LFR 
		ldbDisplayRaid = true,	-- LDB Show Raid
		ldbDisplayRoll = true,	-- LDB Show Bonus Roll
		ldbDisplayBoss = true,	-- LDB Show World Boss
		
		-- Toon indicators
		ToolLevel = true,			-- show player level
		TooniLevel = true,			-- show iLevel
		TooniELevel = false,		-- show iELevel
		ToonActivity = true,		-- show the daily/weekly activity indicators
		ToonCharms = true,			-- show Charms
		ToonProfCD = true,			-- Show the profession cooldowns
		ToonFarm = false,			-- Show the Farm details
		ToonTimeless = false,
		ToonHP = false,
		ToonCPCap = false,
		ToonCP = false,
		ToonApexis = true,
		ToonGarRes = false,
		
		-- Charm Indicators
		charmLesser = false,
		charmElder = false,
		charmMogu = false,
		charmWarSeal = false,
		charmFate = true,
		
		-- Raid Indicators
		RaidMV = false,
		RaidHoF = false,
		RaidToES = false,
		RaidToT = false,
		RaidSoO = false,
		RaidHM = true,
		RaidBRF = true,
		
		-- World Boss Indicators
		BossSha = false,
		BossGalleon = false,
		BossNalak = false,
		BossOondasta = false,
		BossCelestial = false,
		BossOrdos = false,
		BossDrov = true,
		BossTarina = true,
		BossRukhmar = true,
		
		-- Activity Indicators
		ActivityD = true,
		ActivityC = true,
		ActivityH = true,
		ActivityHS = false,
		ActivityS = false,
		ActivityR = true,

		-- Profession Cooldown Indicators
		ProfAlc = false,
		ProfBS = false,
		ProfBS2 = false,
		ProfTailor = false,
		ProfTailor2 = false,
		ProfEnch = false,
		ProfScribe = false,
		ProfJCGem = false,
		ProfJCHeart = false,
		ProfLW = false,
		ProfLW2 = false,
		ProfEng = false,
		
		ProfWoDAlc1Text = true,
		ProfWoDAlc2Text = false,
		ProfWoDBS1Text = true,
		ProfWoDBS2Text = false,
		ProfWoDEnc1Text = true,
		ProfWoDEnc2Text = false,
		ProfWoDEng1Text = true,
		ProfWoDEng2Text = false,
		ProfWoDScribe1Text = true,
		ProfWoDScribe2Text = false,
		ProfWoDJC1Text = true,
		ProfWoDJC2Text = false,
		ProfWoDLW1Text = true,
		ProfWoDLW2Text = false,
		ProfWoDTailor1Text = true,
		ProfWoDTailor2Text = false,
		

		Background = {
			Texture = "Blizzard Tabard Background",
			BorderTexture = "Blizzard Tooltip",
			Color = {r = 0.5, g = 0.5, b = 0.5, a = 1,},
			AltLineColor = {r = 0.5, g = 0.5, b = 0.5, a = 1,},
			BorderColor = {r = 0.95, g = 1, b = 1, a = 1,},
			Tile = false,
			AltLine = true,
			TileSize = 32,
			EdgeSize = 10,
		},


		-- old values
		ToonVPCap = nil,
		ToonVP = nil,
		ToonJP = nil,
		ActivityCoTK = nil,
		ActivityEH = nil,
		ActivityPM = nil,
		cinfoVP = nil,
		cinfoVPCap = nil,
		cinfoJP = nil,
	},
    char = {
        debug = false,          -- Debug mode
    }
};

